from distutils.core import setup
from setuptools import setup
from setuptools.dist import Distribution

setup(
    name="tstamp",
    version="1.0.0",
    description="A library which provides a higher level interface for creating and formatting timestamps.",
    url="https://github.com/iLoveTux/timestamp",
    author="iLoveTux",
    author_email="ilovetux@ymail.com",
    license="MIT",
    keywords="time timestamp epoch"
)

